@@ -16,7 +16,7 @@ from pypistats import cli
         ("2018-12", ("2018-12-01", "2018-12-31")),
     ],
 )
-def test__month(test_input, expected):
+def test__month(test_input: str, expected: str) -> None:
     # Act
     first, last = cli._month(test_input)
 
@@ -32,7 +32,7 @@ def test__month(test_input, expected):
         ("2018-12-25", ("2018-11-01", "2018-11-30")),
     ],
 )
-def test__last_month(test_input, expected):
+def test__last_month(test_input: str, expected: str) -> None:
     # Act
     with freeze_time(test_input):
         first, last = cli._last_month()
@@ -49,7 +49,7 @@ def test__last_month(test_input, expected):
         ("2019-12-25", "2019-12-01"),
     ],
 )
-def test__this_month(test_input, expected):
+def test__this_month(test_input: str, expected: str) -> None:
     # Act
     with freeze_time(test_input):
         first = cli._this_month()
@@ -73,7 +73,7 @@ def test__this_month(test_input, expected):
         ("december", "%B", "2018-12"),
     ],
 )
-def test__month_name_to_yyyy_mm(name, date_format, expected):
+def test__month_name_to_yyyy_mm(name: str, date_format: str, expected: str) -> None:
     # Act
     output = cli._month_name_to_yyyy_mm(name, date_format)
 
@@ -82,18 +82,18 @@ def test__month_name_to_yyyy_mm(name, date_format, expected):
 
 
 @pytest.mark.parametrize("test_input", ["2018-01-12", "2018-07-12", "2018-12-12"])
-def test__valid_yyyy_mm_dd_valid(test_input):
+def test__valid_yyyy_mm_dd_valid(test_input: str) -> None:
     assert test_input == cli._valid_yyyy_mm_dd(test_input)
 
 
 @pytest.mark.parametrize("test_input", ["asdfsdssd", "2018-99-99", "2018-xx"])
-def test__valid_yyyy_mm_dd_invalid(test_input):
+def test__valid_yyyy_mm_dd_invalid(test_input: str) -> None:
     with pytest.raises(argparse.ArgumentTypeError):
         cli._valid_yyyy_mm_dd(test_input)
 
 
 @pytest.mark.parametrize("test_input", ["2018-01", "2018-07", "2018-12"])
-def test__valid_yyyy_mm_valid(test_input):
+def test__valid_yyyy_mm_valid(test_input: str) -> None:
     assert test_input == cli._valid_yyyy_mm(test_input)
 
 
@@ -112,18 +112,18 @@ def test__valid_yyyy_mm_valid(test_input):
         ("december", "2018-12"),
     ],
 )
-def test__valid_yyyy_mm_valid_name(test_input, expected):
+def test__valid_yyyy_mm_valid_name(test_input: str, expected: str) -> None:
     assert expected == cli._valid_yyyy_mm(test_input)
 
 
 @pytest.mark.parametrize("test_input", ["dfkgjskfjgk", "2018-99", "2018-xx"])
-def test__valid_yyyy_mm_invalid(test_input):
+def test__valid_yyyy_mm_invalid(test_input: str) -> None:
     with pytest.raises(argparse.ArgumentTypeError):
         cli._valid_yyyy_mm(test_input)
 
 
 @pytest.mark.parametrize("test_input", ["2019-01-21", "2019-01"])
-def test__valid_yyyy_mm_optional_dd_valid(test_input):
+def test__valid_yyyy_mm_optional_dd_valid(test_input: str) -> None:
     assert test_input == cli._valid_yyyy_mm_optional_dd(test_input)
 
 
@@ -131,24 +131,24 @@ def test__valid_yyyy_mm_optional_dd_valid(test_input):
 @pytest.mark.parametrize(
     "test_input, expected", [("jan", "2019-01"), ("february", "2019-02")]
 )
-def test__valid_yyyy_mm_optional_dd_valid_name(test_input, expected):
+def test__valid_yyyy_mm_optional_dd_valid_name(test_input: str, expected: str) -> None:
     assert expected == cli._valid_yyyy_mm_optional_dd(test_input)
 
 
 @pytest.mark.parametrize("test_input", ["dkvnf", "2018-99", "2018-xx"])
-def test__valid_yyyy_mm_optional_dd_invalid(test_input):
+def test__valid_yyyy_mm_optional_dd_invalid(test_input: str) -> None:
     with pytest.raises(argparse.ArgumentTypeError):
         cli._valid_yyyy_mm_optional_dd(test_input)
 
 
 class __Args:
-    def __init__(self):
+    def __init__(self) -> None:
         self.json = False  # type: bool
         self.format = "markdown"  # type: str
 
 
 @pytest.mark.parametrize("test_input, expected", [(False, "markdown"), (True, "json")])
-def test__define_format_json_flag(test_input, expected):
+def test__define_format_json_flag(test_input: bool, expected: str) -> None:
     # Arrange
     args = __Args()
     args.json = test_input
@@ -161,7 +161,7 @@ def test__define_format_json_flag(test_input, expected):
 
 
 @pytest.mark.parametrize("test_input", ["json", "markdown"])
-def test__define_format_format_flag(test_input):
+def test__define_format_format_flag(test_input: str) -> None:
     # Arrange
     args = __Args()
     args.json = False
